==> alliance-5.0-20020701.tar.gz: alliance-5.0/vasy/src/vasy_drvvex.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                     VASY                          |
|                                                             |
| File    :                 vasy_drvvex.h                     |
|                                                             |
| Authors :                Jacomme Ludovic                    |
|                                                             |
| Date    :                   25.08.97                        |
|                                                             |
\------------------------------------------------------------*/

# ifndef VASY_DRVVEX_H
# define VASY_DRVVEX_H

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define VASY_DRIVE_VEX_LENGTH        80

# define VASY_DRIVE_VEX_VECTOR_MASK   VEX_NODE_USER1_MASK

/*------------------------------------------------------------\
|                                                             |
|                            Macro                            |
|                                                             |
\------------------------------------------------------------*/

# define VasyDriveVexExprVhdl( F, R, E )     (VasyDriveVexExpr( (F), (R), (E), 0 ))
# define VasyDriveVexExprVerilog( F, R, E )  (VasyDriveVexExpr( (F), (R), (E), 1 ))

# define IsVasyDriveVexVector( N )    ( (N)->TYPE &   VASY_DRIVE_VEX_VECTOR_MASK )
# define SetVasyDriveVexVector( N )   ( (N)->TYPE |=  VASY_DRIVE_VEX_VECTOR_MASK )
# define ClearVasyDriveVexVector( N ) ( (N)->TYPE &= ~VASY_DRIVE_VEX_VECTOR_MASK )

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void VasyDriveVexExpr();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/vasy/src/vasy_drvvex.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU General Public |
| License as  published by the Free Software Foundation;      |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/

/*------------------------------------------------------------\
|                                                             |
| Tool    :                     VASY                          |
|                                                             |
| File    :                 vasy_drvvex.h                     |
|                                                             |
| Authors :                Jacomme Ludovic                    |
|                                                             |
| Date    :                   25.08.97                        |
|                                                             |
\------------------------------------------------------------*/

# ifndef VASY_DRVVEX_H
# define VASY_DRVVEX_H

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define VASY_DRIVE_VEX_LENGTH        80

# define VASY_DRIVE_VEX_VECTOR_MASK   VEX_NODE_USER1_MASK

/*------------------------------------------------------------\
|                                                             |
|                            Macro                            |
|                                                             |
\------------------------------------------------------------*/

# define VasyDriveVexExprVhdl( F, R, E )     (VasyDriveVexExpr( (F), (R), (E), 0 ))
# define VasyDriveVexExprVerilog( F, R, E )  (VasyDriveVexExpr( (F), (R), (E), 1 ))

# define IsVasyDriveVexVector( N )    ( (N)->TYPE &   VASY_DRIVE_VEX_VECTOR_MASK )
# define SetVasyDriveVexVector( N )   ( (N)->TYPE |=  VASY_DRIVE_VEX_VECTOR_MASK )
# define ClearVasyDriveVexVector( N ) ( (N)->TYPE &= ~VASY_DRIVE_VEX_VECTOR_MASK )

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  extern void VasyDriveVexExpr();

# endif
